ASReview LAB user guide
=======================

ASReview LAB is a web-based application for the ASReview systematic review
software. It is designed to make the process of systematic reviewing more
efficient and transparent. The application is built on top of the ASReview
Python package, which is a state-of-the-art tool for active learning based
systematic reviews.

.. seealso::

    Questions can be asked on `GitHub Discussions
    <https://github.com/asreview/asreview/discussions>`__. For bug reports and
    feature requests, please submit an issue on `GitHub
    <https://github.com/asreview/asreview/issues/new/choose>`__.

.. toctree::
    :caption: Introduction
    :maxdepth: 2

    about
    products
    research
    contribute


.. toctree::
    :caption: Install and start
    :maxdepth: 2

    installation
    start
    troubleshooting


.. toctree::
    :caption: Data
    :maxdepth: 2

    data
    data_format
    data_labeled


.. toctree::
    :caption: Screening and projects
    :maxdepth: 2

    project_create
    screening
    progress
    manage

.. toctree::
    :caption: Simulation
    :maxdepth: 2

    simulation_overview
    simulation_webapp
    simulation_cli
    simulation_results
    simulation_api_example
